@@ -1,21 +1,21 @@
-/* vi:set sw=2 sts=2 ts=2 et ai: */
+/* vi:set expandtab sw=2 sts=2: */
 /*-
- * Copyright (c) 2008 Jannis Pohlmann <jannis@xfce.org>.
+ * Copyright (c) 2008 Jannis Pohlmann <jannis@xfce.org>
  *
- * This program is free software; you can redistribute it and/or modify 
- * it under the terms of the GNU General Public License as published by 
- * the Free Software Foundation; either version 2 of the License, or (at 
- * your option) any later version.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful, but 
- * WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU 
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License 
- * along with this program; if not, write to the Free Software 
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
- * MA  02111-1307  USA
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, 
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,13 +52,13 @@ static guint button_signals[LAST_SIGNAL];
 
 /* Icons for different volume levels */
 static const char *icons[] = {
-  AUDIO_VOLUME_00,
-  AUDIO_VOLUME_01,
-  AUDIO_VOLUME_02,
-  AUDIO_VOLUME_03,
-  AUDIO_VOLUME_04,
-  AUDIO_VOLUME_05,
-  AUDIO_VOLUME_06,
+  "xfce4-mixer-volume-muted",
+  "xfce4-mixer-volume-ultra-low",
+  "xfce4-mixer-volume-low",
+  "xfce4-mixer-volume-low-medium",
+  "xfce4-mixer-volume-medium",
+  "xfce4-mixer-volume-high",
+  "xfce4-mixer-volume-very-high",
   NULL
 };
 
@@ -201,8 +201,8 @@ xfce_volume_button_init (XfceVolumeButton *button)
   /* Allocate array for preloaded icons */
   button->pixbufs = g_new0 (GdkPixbuf*, G_N_ELEMENTS (icons)-1);
 
-  /* Create adjustment for the button (from 0.0 to 1.0 in 5% steps) */
-  button->adjustment = gtk_adjustment_new (0.0, 0.0, 1.0, 0.05, 0.05, 0.2);
+  /* Create adjustment for the button (from 0.0 to 1.0 in 1% steps) */
+  button->adjustment = gtk_adjustment_new (0.0, 0.0, 1.0, 0.01, 0.01, 0.1);
 
   /* Create a new scaled image for the button icon */
   button->image = xfce_scaled_image_new ();
@@ -216,7 +216,7 @@ xfce_volume_button_init (XfceVolumeButton *button)
 
   /* Connect to button signals */
 #if 0
-  /* UNSED FOR NOW DUE TO TOO MUCH PROBLEMS WITH KEYBOARD FOCUS GRABBING */
+  /* UNUSED FOR NOW DUE TO TOO MUCH PROBLEMS WITH KEYBOARD FOCUS GRABBING */
   g_signal_connect (G_OBJECT (button), "key-press-event", G_CALLBACK (xfce_volume_button_key_pressed), button);
 #endif
   g_signal_connect (G_OBJECT (button), "button-press-event", G_CALLBACK (xfce_volume_button_button_pressed), button);
